.. _saml:

******************************************
Base classes representing Saml2.0 elements
******************************************

:Author: Roland Hedberg
:Version: |version|

.. module:: SAML2
   :synopsis: Base classes representing Saml2.0 elements.
   
Module
==========

.. automodule:: saml2.saml
   :members: 

